@@ -248,7 +248,7 @@ class OdtGenerator(DocumentGenerator):
         self.document.automaticstyles.addElement(frame_style_rotated)
 
     def addText(self, data_box):
-        text = unicode(data_box.getText(), 'utf-8')
+        text = data_box.getText().decode('utf-8')
         frame_style = Style(name='FrameStyle', family = 'graphic')
         debug('Angle: ', data_box.text_data.angle)
         angle = data_box.text_data.angle
@@ -368,7 +368,7 @@ class PlaintextGenerator(DocumentGenerator):
             # This will create a new file or **overwrite an existing file
             f = open(self.name, "w")
             try:
-                f.write(self.text) # Write text to file
+                f.write(self.text.encode('utf-8'))
             finally:
                 f.close() # Close the file
         except IOError:
